@@ -120,6 +120,15 @@ e_cal_util_copy_timezone (const ICalTimezone *zone)
 	if (!zone_copy)
 		return NULL;
 
+	/* If the original component is one of the built-in, then libcal
+	   loads it during the i_cal_timezone_get_component() call and
+	   assigns a component to it. */
+	comp = i_cal_timezone_get_component (zone_copy);
+	if (comp) {
+		g_object_unref (comp);
+		return zone_copy;
+	}
+
 	comp = i_cal_timezone_get_component (zone);
 	if (comp) {
 		ICalComponent *comp_copy;
@@ -143,7 +152,7 @@ read_line (const gchar *string)
 		if (!line_str)
 			line_str = g_string_new ("");
 
-		line_str = g_string_append_c (line_str, *string);
+		g_string_append_c (line_str, *string);
 		if (*string == '\n')
 			break;
 	}
@@ -186,7 +195,7 @@ e_cal_util_parse_ics_string (const gchar *string)
 		if (!comp_str)
 			comp_str = g_string_new (line);
 		else
-			comp_str = g_string_append (comp_str, line);
+			g_string_append (comp_str, line);
 
 		if (strncmp (line, "END:VCALENDAR", 13) == 0) {
 			ICalComponent *tmp;
